pub struct NodeConnections {
inner: SmallVec<[Option<Connection>; 3]>,
alloc_map: AllocMap<MAX_CONNECTIONS>,
count: usize,
active: Option<(usize, usize)>,
}Expand description
Keeps track of node connections. Stores them in a vector, with alloc_map keeping track of which spaces in the vector
are allocated and which are not. Empty spaces are marked with Option::None in the inner vector.
Fields
inner: SmallVec<[Option<Connection>; 3]>alloc_map: AllocMap<MAX_CONNECTIONS>count: usizeactive: Option<(usize, usize)>Indices of connections which make up an active connection. Stored in order, meaning a[0] < a[1] (a[0] != a[1], an active connection cannot be between itself).
Implementations
Sourceimpl NodeConnections
impl NodeConnections
fn find_first_two(&self) -> Option<[usize; 2]>
Sourcepub fn add(&mut self, c: Connection) -> Result<usize, Connection>
pub fn add(&mut self, c: Connection) -> Result<usize, Connection>
Tries to add the connection. If the allocation succeded, returns the connections ID. If there is no space left, returns the connection wrapped in an error.
Sourcepub fn remove(&mut self, index: usize) -> bool
pub fn remove(&mut self, index: usize) -> bool
Attempts to remove the given connection. If no such connection exists, returns false, otherwise returns true.
Sourcepub fn remove_for(&mut self, segment: Entity) -> bool
pub fn remove_for(&mut self, segment: Entity) -> bool
Attempts to remove a connection with the given segment If no such connection exists, returns false, otherwise returns true.
Sourcepub fn iter(&self) -> impl Iterator<Item = &Connection>
pub fn iter(&self) -> impl Iterator<Item = &Connection>
Returns an iterator over the inner connections
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns whether there are no connections, similar to Vec::is_empty()
Sourcepub fn activate(&mut self, c0: usize, c1: usize)
pub fn activate(&mut self, c0: usize, c1: usize)
Sets connections with indices c0 and c1 as active.
Sourcepub fn deactivate(&mut self)
pub fn deactivate(&mut self)
Removes the active connection.
Sourcepub fn active(&self) -> Option<(&Connection, &Connection)>
pub fn active(&self) -> Option<(&Connection, &Connection)>
Returns the active connection.
fn advance(c0: &mut usize, c1: &mut usize, len: usize)
Sourcepub fn activate_next(&mut self)
pub fn activate_next(&mut self)
Does nothing if there aren’t enough connections present (n < 2).
Sourcepub fn get_active_for(&self, segment: Entity) -> Option<&Connection>
pub fn get_active_for(&self, segment: Entity) -> Option<&Connection>
Returns the other side of the active connection for the segment.
None if segment isn’t part of the active connection.